==> TruetypeText-2.0.1.zip: TruetypeText/lang/fr_FR.php <==
<?php
$lang['addfilter'] = 'Ajouter un filtre d&rsquo;image';
$lang['additional'] = 'Texte additionnel (exemple : "class=myclass")';
$lang['addmirror'] = 'Ajouter un effet mirroir';
$lang['addpredefineddouble'] = 'Ajouter un style "double" pr&eacute;d&eacute;fini';
$lang['addpredefinedghost'] = 'Ajouter un style "empreinte" pr&eacute;d&eacute;fini';
$lang['addpredefinedmirror'] = 'Ajouter un style "miroir" pr&eacute;d&eacute;fini';
$lang['addpredefinedshadow'] = 'Ajouter un style "ombre" pr&eacute;d&eacute;fini';
$lang['addreplacement'] = 'Ajouter un remplacement automatique';
$lang['addstyle'] = 'Ajouter un nouveau style';
$lang['addtext'] = 'Ajouter un &eacute;l&eacute;ment de texte';
$lang['addtransformation'] = 'Ajouter une transformation';
$lang['angle'] = 'Angle';
$lang['areyousure'] = '&ecirc;tes-vous sur ?';
$lang['Autoreplace'] = 'Remplacements automatiques';
$lang['back'] = 'Retour';
$lang['backgroundcolor'] = 'Couleur de fonds';
$lang['blur'] = 'Flou';
$lang['cachecleared'] = 'Le cache a &eacute;t&eacute; vid&eacute;, sauf les fichiers de pr&eacute;visualisation';
$lang['clearcache'] = 'Vider le cache';
$lang['color'] = 'Couleur';
$lang['copyelement'] = 'Dupliquer l&rsquo;&eacute;l&eacute;ment';
$lang['copystyle'] = 'Dupliquer le style';
$lang['downopacity'] = 'Opacit&eacute; du bas';
$lang['deletefont'] = 'Effacer le fichier de police';
$lang['deleteelement'] = 'Effacer l&rsquo;&eacute;l&eacute;ment';
$lang['deletereplacement'] = 'Annuler le remplacement automatique';
$lang['deletestyle'] = 'Effacer le style';
$lang['deltax'] = 'D&eacute;calage horizontal';
$lang['deltay'] = 'D&eacute;calage vertical';
$lang['details'] = 'D&eacute;tails';
$lang['edge'] = 'D&eacute;tection de bords';
$lang['editreplacement'] = 'Modifier le remplacement automatique';
$lang['editstyle'] = 'Modifier le style';
$lang['effect'] = 'Filtre';
$lang['elements'] = 'El&eacute;ments de style';
$lang['emboss'] = 'Gaufrage';
$lang['example'] = 'Exemple';
$lang['error_angle'] = 'L&rsquo;angle doit &ecirc;tre num&eacute;rique';
$lang['error_colorformat'] = 'La couleur doit avoir un format similaire &agrave; #RRGGBB ou #RRGGBBTT (R: rouge, G: vert, B: bleu, T: transparence)';
$lang['error_deletefont'] = 'Impossible d&rsquo;effacer le fichier de police. V&eacute;rifier les permissions.';
$lang['error_delta'] = 'Les d&eacute;calage (horizontal et vertical) doivent &ecirc;tre des valeurs num&eacute;riques.';
$lang['error_emptyname'] = 'Le nom ne peut &ecirc;tre vide.';
$lang['error_namealreadyexists'] = 'Ce nom est d&eacute;j&agrave; utilis&eacute;.';
$lang['error_nameisnumeric'] = 'Le nom doit contenir des caract&egrave;res alphab&eacute;tiques';
$lang['error_nofontfile'] = 'La premi&egrave;re chose &agrave; faire est de t&eacute;l&eacute;charger un fichier de police';
$lang['error_maxwidth'] = 'La largeur maximale doit &ecirc;tre num&eacute;rique, nulle ou positive.';
$lang['error_noelement'] = 'Un style doit contenir au minimum un &eacute;l&eacute;ment de texte';
$lang['error_nofilesuploaded'] = 'Aucun fichier t&eacute;l&eacute;charger';
$lang['error_nostyle'] = 'Il faut avant tout d&eacute;finir un style';
$lang['error_notag'] = 'La balise HTML est obligatoire';
$lang['error_nottffunctions'] = 'Votre version de PHP a &eacute;t&eacute; compil&eacute;e sans le support des fonctions imagettftext et imagettfbbox. Ce module ne fonctionnera pas.';
$lang['error_ratioinvalid'] = 'La hauteur de l&rsquo;effet miroir doit &ecirc;tre une valeur num&eacute;rique positive.';
$lang['error_size'] = 'La taille doit &ecirc;tre une valeur num&eacute;rique positive.';
$lang['error_transparency'] = 'La transparence doit &ecirc;tre une valeur num&eacute;rique entre 0 et 100.';
$lang['error_unabletomoveelement'] = 'Il est impossible de d&eacute;placer cet &eacute;l&eacute;ment.';
$lang['error_unabletosavereplacement'] = 'Il est impossible d&rsquo;enregistrer ce remplacement automatique';
$lang['error_unabletosavestyle'] = 'Il est impossible d&rsquo;enregistrer ce style';
$lang['error_unknownelementtype'] = 'Type d&rsquo;&eacute;l&eacute;ment inconnu';
$lang['error_unknownfont'] = 'Fichier de police inconnu';
$lang['error_unknownpredefinedstyle'] = 'Style pr&eacute;d&eacute;fini inconnu';
$lang['filenumberandsize'] = 'Le cache contient %s fichiers occupant  %s sur le disque';
$lang['fileuploaded'] = 'Le fichier a &eacute;t&eacute; t&eacute;l&eacute;charg&eacute;';
$lang['flipboth'] = 'Retournement vertical et horizontal';
$lang['fliphorizontal'] = 'Retournement horizontal';
$lang['flipvertical'] = 'Retournement vertical';
$lang['fontfile'] = 'Fichier de police';
$lang['fontfiles'] = 'Fichiers de police';
$lang['Fonts'] = 'Fichiers de police';
$lang['format'] = 'Format de fichier image';
$lang['fulllineheight'] = 'Hauteur de texte uniforme';
$lang['import'] = 'Importer';
$lang['maxwidth'] = 'Largeur maximale';
$lang['mirror'] = 'Effet miroir';
$lang['moveelementdown'] = 'D&eacute;placer l&rsquo;&eacute;l&eacute;ment vers le bas';
$lang['moveelementup'] = 'D&eacute;placer l&rsquo;&eacute;l&eacute;ment vers le haut';
$lang['name'] = 'Nom';
$lang['number'] = 'n';
$lang['noreplacements'] = '(aucun remplacement d&eacute;fini)';
$lang['nofontfiles'] = 'Aucun fichier de police n&rsquo;est pr&eacute;sent';
$lang['nostyles'] = '(aucun style d&eacute;fini)';
$lang['notused'] = '(non utilis&eacute;)';
$lang['parameters'] = 'Param&egrave;tres';
$lang['pictureperword'] = 'Une image par mot';
$lang['predefinedstyleadded'] = 'Le style "%s" a &eacute;t&eacute; ajout&eacute;';
$lang['predefinedstyles'] = 'Styles pr&eacute;d&eacute;finis';
$lang['Properties'] = 'Propri&eacute;t&eacute;s';
$lang['ratio'] = 'Hauteur';
$lang['replacefunction'] = 'Ev&eacute;nement pendant lequel se produit le remplacement';
$lang['replacefunctionsaved'] = 'Le remplacement automatique a &eacute;t&eacute; enregistr&eacute;.';
$lang['replacementdisabled'] = '(D&eacute;sactiv&eacute;)';
$lang['replacemoment'] = 'Circonstance d&acute;appel du remplacement automatique';
$lang['rotate90'] = 'Rotation &agrave; 90&deg;';
$lang['rotate270'] = 'Rotation &agrave; 270&deg;';
$lang['sampletext'] = 'Phrase exemple';
$lang['sampletextsaved'] = 'Phrase exemple enregistr&eacute;e';
$lang['save'] = 'Enregistrer';
$lang['size'] = 'Taille';
$lang['sharpen'] = 'Accentuer';
$lang['style'] = 'Style';
$lang['stylename'] = 'Nom';
$lang['Styles'] = 'Styles';
$lang['stylesaved'] = 'Le style a &eacute;t&eacute; enregistr&eacute;';
$lang['tag'] = 'Balise HTML';
$lang['tagtouse'] = 'Balise &agrave; utiliser dans une page ou dans un gabarit';
$lang['text'] = 'Texte';
$lang['type'] = 'Type';
$lang['transformation'] = 'Transformation';
$lang['transparency'] = 'Transparence';
$lang['transparent'] = 'Fonds transparent';
$lang['unknownstyle'] = 'Style inconnu';
$lang['upload'] = 'T&eacute;l&eacute;charger un fichier';
$lang['upopacity'] = 'Opacit&eacute; du haut';
$lang['usedinstyles'] = 'Styles utilisant cette police';



$lang['description'] = 'Le module TruetypeText permet d&rsquo;afficher du texte dans n&rsquo;importe quelle police Truetype, avec possibilit&eacute; d&rsquo;effets vari&eacute;s.';
$lang['admindescription'] = 'Permet d&rsquo;afficher du texte dans n&rsquo;importe quelle police Truetype, avec possibilit&eacute; d&rsquo;effets vari&eacute;s.';
$lang['friendlyname'] = 'Embellisseur de texte';
$lang['help'] = <<<EOF
	<h3>Que fait ce module ?</h3>
	<p>TruetypeText est un module permettant d&apos;&eacute;crire du texte avec des fichiers de polices Truetype afin d&apos;enrichir la pr&eacute;sentation de votre site</p>
	<h3>Comment l&apos;utiliser ?</h3>
	<p>La fa&ccedil;on la plus simple d&apos;utiliser ce module consiste &agrave; ins&eacute;rer une balise <code>{cms_module module="TruetypeText" style="votre style" text="texte &agrave; enrichir"}</code>.  Les param&egrave;tres &agrave; renseigner sont list&eacute;s ci-dessous.</p>
	<ul>
		<li><strong>text</strong> : le texte &agrave; &eacute;crire. Vous pouvez aussi utiliser l&apos;un des noms r&eacute;serv&eacute;s suivants :
			<ul>
				<li><strong>%title</strong> : affichera le titre de la page</li>
				<li><strong>%menutext</strong> : affichera le texte de menu de la page</li>
				<li><strong>%sitename</strong> : affichera le nom du site</li>
				<li><strong>%description</strong> : affichera l&apos;attribut title de la page</li>
			</ul>
		</li>
		<li><strong>style</strong> : le nom du style &agrave; utiliser</li>
	</ul>
	<h3>Construction d&apos;un style</h3>
	<p>Chaque style comporte des param&egrave;tres et des &eacute;l&eacute;ments :</p>
	<ul>
		<li><strong>Param&egrave;tres</strong>
			<ul>
				<li><strong>Nom</strong> : le nom du style</li>
				<li><strong>Couleur de fonds</strong> : couleur de fonds du style</li>
				<li><strong>Format de fichier image</strong> : format de d&apos;image au choix (gif, jpg ou png)</li>
				<li><strong>Hauteur de texte uniforme</strong> : si cette option est coch&eacute;e, toutes les images de texte faites avec ce style auront la m&ecirc;me hauteur. Ceci peut &ecirc;tre utile si le texte comporte des jambages.</li>
				<li><strong>Largeur maximale</strong> : si cette valeur est non nulle, le module renverra le texte &agrave; la ligne &agrave; chaque fois que cette largeur sera d&eacute;pass&eacute;e</li>
				<li><strong>Une image par mot</strong> : si cette option est coch&eacute;e, le module produira une image par mot, plutot qu&apos;une image contenant tout le texte. Il peut &ecirc;tre utile de cocher en m&ecirc;me temps l&apos;option "Hauteur de texte uniforme".</li>
				<li><strong>Fonds transparent</strong> : si cette option est coch&eacute;e, Le fond sera transparent. Ne fonctionne pas avec les images jpg qui ne g&egrave;rent pas la transparence.</li>
			</ul>
		</li>
		<li><strong>El&eacute;ments</strong><br />Les &eacute;l&eacute;ments de style seront appliqu&eacute;s les uns apr&egrave;s les autres au texte. Par exemple : un &eacute;l&eacute;ment de texte, puis un filtre flou, puis un effet miroir.
			<ul>
				<li><strong>El&eacute;ment de texte</strong> : &eacute;criture du texte dans une police truetype sp&eacute;cifique. Il est possible d&apos;agir sur la taille du texte, la couleur, la transparence. il est aussi possible de d&eacute;caler le texte horizontalement ou verticalement, ou de l&apos;incliner, ce qui est utile si plusieurs &eacute;l&eacute;ments de texte sont utilis&eacute;s.</li>
				<li><strong>Filtre d&apos;image</strong> : les filtres d&apos;images permettent d&apos;obtenir des effets particuliers : flou, gaufrage, accentuation, d&eacute;tection de bords</li>
				<li><strong>Effet miroir</strong> : il s&apos;agit d&apos;appliquer &agrave; l&apos;image un effet miroir horizontal, comme le reflet dans un lac.</li>
				<li><strong>Transformation</strong> : une transformation peut &ecirc;tre une rotation ou un retournement de l&apos;image.</li>
			</ul>
		</li>
	</ul>
	<h3>Remplacements automatiques</h3>
	<p>Le module TruetypeText permet en outre d&apos;effectuer automatiquement des remplacements dans le texte d&apos;une page. Il vous appartient de choisir le moment o&ugrave; intervient ce remplacement automatique :
	<ul>
		<li><strong>ContentPostCompile</strong> (recommand&eacute;) : les remplacements seront effectu&eacute;s apr&egrave;s compilation du contenu et avant que ce contenu soit envoy&eacute; en cache. Ceci permet d&apos;&eacute;conomiser des ressources car la fonction ne sera pas appel&eacute;e &agrave; nouveau si la page est d&eacute;j&agrave; en cache.</li>
		<li><strong>ContentPostRender</strong> : les remplacements seront effectu&eacute;s &agrave; chaque affichage de la page, ce qui peut ralentir l&apos;affichage.</li>
		<li><strong>D&eacute;sactiv&eacute;</strong> : aucun remplacement automatique ne sera effectu&eacute;</li>
	</ul>
	</p>

	<p>Vous pouvez cr&eacute;er plusieurs remplacements automatiques. Chaque remplacement contient les &eacute;l&eacute;ments suivants :
	<ul>
		<li><strong>Balise</strong> : Une balise html (exemple : "h1", "h2", "em", "strong"). Par exemple, si vous choisissez h1 Le moteur de remplacement cherchera tous les &eacute;l&eacute;ments de titre de premier niveau</li>
		<li><strong>Texte additionnel</strong> : un attribut html (exemple : "class=&apos;jolitexte&apos;"). Ceci permet de restreindre le remplacement aux &eacute;l&eacute;ments d&apos;une classe donn&eacute;e par exemple.</li>
		<li><strong>Style</strong> : un style TruetypeText &agrave; utiliser pour le remplacement.</li>
	</ul>
	</p>
EOF;

?>

==> TruetypeText-2.0.2.zip: TruetypeText/lang/fr_FR.php <==
<?php
$lang['addfilter'] = 'Ajouter un filtre d&apos;image';
$lang['additional'] = 'Texte additionnel (exemple : "class=myclass")';
$lang['addmirror'] = 'Ajouter un effet mirroir';
$lang['addpredefineddouble'] = 'Ajouter un style "double" pr&eacute;d&eacute;fini';
$lang['addpredefinedghost'] = 'Ajouter un style "empreinte" pr&eacute;d&eacute;fini';
$lang['addpredefinedmirror'] = 'Ajouter un style "miroir" pr&eacute;d&eacute;fini';
$lang['addpredefinedshadow'] = 'Ajouter un style "ombre" pr&eacute;d&eacute;fini';
$lang['addreplacement'] = 'Ajouter un remplacement automatique';
$lang['addstyle'] = 'Ajouter un nouveau style';
$lang['addtext'] = 'Ajouter un &eacute;l&eacute;ment de texte';
$lang['addtransformation'] = 'Ajouter une transformation';
$lang['angle'] = 'Angle';
$lang['areyousure'] = '&ecirc;tes-vous sur ?';
$lang['Autoreplace'] = 'Remplacements automatiques';
$lang['back'] = 'Retour';
$lang['backgroundcolor'] = 'Couleur de fonds';
$lang['blur'] = 'Flou';
$lang['cachecleared'] = 'Le cache a &eacute;t&eacute; vid&eacute;, sauf les fichiers de pr&eacute;visualisation';
$lang['clearcache'] = 'Vider le cache';
$lang['color'] = 'Couleur';
$lang['copyelement'] = 'Dupliquer l&apos;&eacute;l&eacute;ment';
$lang['copystyle'] = 'Dupliquer le style';
$lang['downopacity'] = 'Opacit&eacute; du bas';
$lang['deletefont'] = 'Effacer le fichier de police';
$lang['deleteelement'] = 'Effacer l&apos;&eacute;l&eacute;ment';
$lang['deletereplacement'] = 'Annuler le remplacement automatique';
$lang['deletestyle'] = 'Effacer le style';
$lang['deltax'] = 'D&eacute;calage horizontal';
$lang['deltay'] = 'D&eacute;calage vertical';
$lang['details'] = 'D&eacute;tails';
$lang['edge'] = 'D&eacute;tection de bords';
$lang['editreplacement'] = 'Modifier le remplacement automatique';
$lang['editstyle'] = 'Modifier le style';
$lang['effect'] = 'Filtre';
$lang['elements'] = 'El&eacute;ments de style';
$lang['emboss'] = 'Gaufrage';
$lang['example'] = 'Exemple';
$lang['error_angle'] = 'L&apos;angle doit &ecirc;tre num&eacute;rique';
$lang['error_colorformat'] = 'La couleur doit avoir un format similaire &agrave; #RRGGBB ou #RRGGBBTT (R: rouge, G: vert, B: bleu, T: transparence)';
$lang['error_deletefont'] = 'Impossible d&apos;effacer le fichier de police. V&eacute;rifier les permissions.';
$lang['error_delta'] = 'Les d&eacute;calage (horizontal et vertical) doivent &ecirc;tre des valeurs num&eacute;riques.';
$lang['error_emptyname'] = 'Le nom ne peut &ecirc;tre vide.';
$lang['error_namealreadyexists'] = 'Ce nom est d&eacute;j&agrave; utilis&eacute;.';
$lang['error_nameisnumeric'] = 'Le nom doit contenir des caract&egrave;res alphab&eacute;tiques';
$lang['error_nofontfile'] = 'La premi&egrave;re chose &agrave; faire est de t&eacute;l&eacute;charger un fichier de police';
$lang['error_maxwidth'] = 'La largeur maximale doit &ecirc;tre num&eacute;rique, nulle ou positive.';
$lang['error_noelement'] = 'Un style doit contenir au minimum un &eacute;l&eacute;ment de texte';
$lang['error_nofilesuploaded'] = 'Aucun fichier t&eacute;l&eacute;charger';
$lang['error_nostyle'] = 'Il faut avant tout d&eacute;finir un style';
$lang['error_notag'] = 'La balise HTML est obligatoire';
$lang['error_nottffunctions'] = 'Votre version de PHP a &eacute;t&eacute; compil&eacute;e sans le support des fonctions imagettftext et imagettfbbox. Ce module ne fonctionnera pas.';
$lang['error_ratioinvalid'] = 'La hauteur de l&apos;effet miroir doit &ecirc;tre une valeur num&eacute;rique positive.';
$lang['error_size'] = 'La taille doit &ecirc;tre une valeur num&eacute;rique positive.';
$lang['error_transparency'] = 'La transparence doit &ecirc;tre une valeur num&eacute;rique entre 0 et 100.';
$lang['error_unabletomoveelement'] = 'Il est impossible de d&eacute;placer cet &eacute;l&eacute;ment.';
$lang['error_unabletosavereplacement'] = 'Il est impossible d&apos;enregistrer ce remplacement automatique';
$lang['error_unabletosavestyle'] = 'Il est impossible d&apos;enregistrer ce style';
$lang['error_unknownelementtype'] = 'Type d&apos;&eacute;l&eacute;ment inconnu';
$lang['error_unknownfont'] = 'Fichier de police inconnu';
$lang['error_unknownpredefinedstyle'] = 'Style pr&eacute;d&eacute;fini inconnu';
$lang['filenumberandsize'] = 'Le cache contient %s fichiers occupant  %s sur le disque';
$lang['fileuploaded'] = 'Le fichier a &eacute;t&eacute; t&eacute;l&eacute;charg&eacute;';
$lang['flipboth'] = 'Retournement vertical et horizontal';
$lang['fliphorizontal'] = 'Retournement horizontal';
$lang['flipvertical'] = 'Retournement vertical';
$lang['fontfile'] = 'Fichier de police';
$lang['fontfiles'] = 'Fichiers de police';
$lang['Fonts'] = 'Fichiers de police';
$lang['format'] = 'Format de fichier image';
$lang['fulllineheight'] = 'Hauteur de texte uniforme';
$lang['import'] = 'Importer';
$lang['maxwidth'] = 'Largeur maximale';
$lang['mirror'] = 'Effet miroir';
$lang['moveelementdown'] = 'D&eacute;placer l&apos;&eacute;l&eacute;ment vers le bas';
$lang['moveelementup'] = 'D&eacute;placer l&apos;&eacute;l&eacute;ment vers le haut';
$lang['name'] = 'Nom';
$lang['number'] = 'n';
$lang['noreplacements'] = '(aucun remplacement d&eacute;fini)';
$lang['nofontfiles'] = 'Aucun fichier de police n&apos;est pr&eacute;sent';
$lang['nostyles'] = '(aucun style d&eacute;fini)';
$lang['notused'] = '(non utilis&eacute;)';
$lang['parameters'] = 'Param&egrave;tres';
$lang['pictureperword'] = 'Une image par mot';
$lang['predefinedstyleadded'] = 'Le style "%s" a &eacute;t&eacute; ajout&eacute;';
$lang['predefinedstyles'] = 'Styles prédéfinis';
$lang['Properties'] = 'Propri&eacute;t&eacute;s';
$lang['ratio'] = 'Hauteur';
$lang['replacefunction'] = 'Ev&eacute;nement pendant lequel se produit le remplacement';
$lang['replacefunctionsaved'] = 'Le remplacement automatique a &eacute;t&eacute; enregistr&eacute;.';
$lang['replacementdisabled'] = '(D&eacute;sactiv&eacute;)';
$lang['replacemoment'] = 'Circonstance d&acute;appel du remplacement automatique';
$lang['rotate90'] = 'Rotation &agrave; 90&deg;';
$lang['rotate270'] = 'Rotation &agrave; 270&deg;';
$lang['sampletext'] = 'Phrase exemple';
$lang['sampletextsaved'] = 'Phrase exemple enregistr&eacute;e';
$lang['save'] = 'Enregistrer';
$lang['size'] = 'Taille';
$lang['sharpen'] = 'Accentuer';
$lang['style'] = 'Style';
$lang['stylename'] = 'Nom';
$lang['Styles'] = 'Styles';
$lang['stylesaved'] = 'Le style a &eacute;t&eacute; enregistr&eacute;';
$lang['tag'] = 'Balise HTML';
$lang['tagtouse'] = 'Balise &agrave; utiliser dans une page ou dans un gabarit';
$lang['text'] = 'Texte';
$lang['type'] = 'Type';
$lang['transformation'] = 'Transformation';
$lang['transparency'] = 'Transparence';
$lang['transparent'] = 'Fonds transparent';
$lang['unknownstyle'] = 'Style inconnu';
$lang['upload'] = 'T&eacute;l&eacute;charger un fichier';
$lang['upopacity'] = 'Opacit&eacute; du haut';
$lang['usedinstyles'] = 'Styles utilisant cette police';



$lang['description'] = 'Le module TruetypeText permet d&apos;afficher du texte dans n&apos;importe quelle police Truetype, avec possibilit&eacute; d&apos;effets vari&eacute;s.';
$lang['admindescription'] = 'Permet d\'afficher du texte dans n\'importe quelle police Truetype, avec possibilité d\'effets variés.';
$lang['friendlyname'] = 'Embellisseur de texte';
$lang['help'] = <<<EOF
	<h3>Que fait ce module ?</h3>
	<p>TruetypeText est un module permettant d&apos;&eacute;crire du texte avec des fichiers de polices Truetype afin d&apos;enrichir la pr&eacute;sentation de votre site</p>
	<h3>Comment l&apos;utiliser ?</h3>
	<p>La fa&ccedil;on la plus simple d&apos;utiliser ce module consiste &agrave; ins&eacute;rer une balise <code>{cms_module module="TruetypeText" style="votre style" text="texte &agrave; enrichir"}</code>.  Les param&egrave;tres &agrave; renseigner sont list&eacute;s ci-dessous.</p>
	<ul>
		<li><strong>text</strong> : le texte &agrave; &eacute;crire. Vous pouvez aussi utiliser l&apos;un des noms r&eacute;serv&eacute;s suivants :
			<ul>
				<li><strong>%title</strong> : affichera le titre de la page</li>
				<li><strong>%menutext</strong> : affichera le texte de menu de la page</li>
				<li><strong>%sitename</strong> : affichera le nom du site</li>
				<li><strong>%description</strong> : affichera l&apos;attribut title de la page</li>
			</ul>
		</li>
		<li><strong>style</strong> : le nom du style &agrave; utiliser</li>
	</ul>
	<h3>Construction d&apos;un style</h3>
	<p>Chaque style comporte des param&egrave;tres et des &eacute;l&eacute;ments :</p>
	<ul>
		<li><strong>Param&egrave;tres</strong>
			<ul>
				<li><strong>Nom</strong> : le nom du style</li>
				<li><strong>Couleur de fonds</strong> : couleur de fonds du style</li>
				<li><strong>Format de fichier image</strong> : format de d&apos;image au choix (gif, jpg ou png)</li>
				<li><strong>Hauteur de texte uniforme</strong> : si cette option est coch&eacute;e, toutes les images de texte faites avec ce style auront la m&ecirc;me hauteur. Ceci peut &ecirc;tre utile si le texte comporte des jambages.</li>
				<li><strong>Largeur maximale</strong> : si cette valeur est non nulle, le module renverra le texte &agrave; la ligne &agrave; chaque fois que cette largeur sera d&eacute;pass&eacute;e</li>
				<li><strong>Une image par mot</strong> : si cette option est coch&eacute;e, le module produira une image par mot, plutot qu&apos;une image contenant tout le texte. Il peut &ecirc;tre utile de cocher en m&ecirc;me temps l&apos;option "Hauteur de texte uniforme".</li>
				<li><strong>Fonds transparent</strong> : si cette option est coch&eacute;e, Le fond sera transparent. Ne fonctionne pas avec les images jpg qui ne g&egrave;rent pas la transparence.</li>
			</ul>
		</li>
		<li><strong>El&eacute;ments</strong><br />Les &eacute;l&eacute;ments de style seront appliqu&eacute;s les uns apr&egrave;s les autres au texte. Par exemple : un &eacute;l&eacute;ment de texte, puis un filtre flou, puis un effet miroir.
			<ul>
				<li><strong>El&eacute;ment de texte</strong> : &eacute;criture du texte dans une police truetype sp&eacute;cifique. Il est possible d&apos;agir sur la taille du texte, la couleur, la transparence. il est aussi possible de d&eacute;caler le texte horizontalement ou verticalement, ou de l&apos;incliner, ce qui est utile si plusieurs &eacute;l&eacute;ments de texte sont utilis&eacute;s.</li>
				<li><strong>Filtre d&apos;image</strong> : les filtres d&apos;images permettent d&apos;obtenir des effets particuliers : flou, gaufrage, accentuation, d&eacute;tection de bords</li>
				<li><strong>Effet miroir</strong> : il s&apos;agit d&apos;appliquer &agrave; l&apos;image un effet miroir horizontal, comme le reflet dans un lac.</li>
				<li><strong>Transformation</strong> : une transformation peut &ecirc;tre une rotation ou un retournement de l&apos;image.</li>
			</ul>
		</li>
	</ul>
	<h3>Remplacements automatiques</h3>
	<p>Le module TruetypeText permet en outre d&apos;effectuer automatiquement des remplacements dans le texte d&apos;une page. Il vous appartient de choisir le moment o&ugrave; intervient ce remplacement automatique :
	<ul>
		<li><strong>ContentPostCompile</strong> (recommand&eacute;) : les remplacements seront effectu&eacute;s apr&egrave;s compilation du contenu et avant que ce contenu soit envoy&eacute; en cache. Ceci permet d&apos;&eacute;conomiser des ressources car la fonction ne sera pas appel&eacute;e &agrave; nouveau si la page est d&eacute;j&agrave; en cache.</li>
		<li><strong>ContentPostRender</strong> : les remplacements seront effectu&eacute;s &agrave; chaque affichage de la page, ce qui peut ralentir l&apos;affichage.</li>
		<li><strong>D&eacute;sactiv&eacute;</strong> : aucun remplacement automatique ne sera effectu&eacute;</li>
	</ul>
	</p>

	<p>Vous pouvez cr&eacute;er plusieurs remplacements automatiques. Chaque remplacement contient les &eacute;l&eacute;ments suivants :
	<ul>
		<li><strong>Balise</strong> : Une balise html (exemple : "h1", "h2", "em", "strong"). Par exemple, si vous choisissez h1 Le moteur de remplacement cherchera tous les &eacute;l&eacute;ments de titre de premier niveau</li>
		<li><strong>Texte additionnel</strong> : un attribut html (exemple : "class=&apos;jolitexte&apos;"). Ceci permet de restreindre le remplacement aux &eacute;l&eacute;ments d&apos;une classe donn&eacute;e par exemple.</li>
		<li><strong>Style</strong> : un style TruetypeText &agrave; utiliser pour le remplacement.</li>
	</ul>
	</p>
EOF;

?>
